@@ -1,9 +1,9 @@
 from urllib.parse import urlparse
-from typing import Optional, Literal
+from typing import Optional, Literal, Union
 
 from . import __VERSION__
 from . import nicolive
-
+from . import ytlive
 
 """
   Public APIs
@@ -25,8 +25,12 @@ class GetLiveProgramError(Exception):
 def get_live_program(
   live_id_or_url: str,
   service: Optional[str],
+  ytlive_api_key: Optional[str],
   useragent: str = default_useragent,
-) -> nicolive.GetNicoliveProgramNicoliveProgramData:
+) -> Union[
+  nicolive.GetNicoliveProgramNicoliveProgramData,
+  ytlive.GetYtliveProgramsSuccessYtliveProgramsData,
+]:
   if service is None:
     service = guess_service(live_id_or_url=live_id_or_url)
 
@@ -50,6 +54,25 @@ def get_live_program(
         raise GetLiveProgramError(nicolive_program_result)
     else:
       raise GetLiveProgramError(nicolive_program_result)
+
+  elif service == 'ytlive':
+    assert ytlive_api_key is not None, 'ytlive_api_key is required'
+
+    ytlive_programs_result = \
+      ytlive.get_ytlive_programs(
+        channel_id=live_id_or_url,
+        useragent=useragent,
+        api_key=ytlive_api_key,
+      )
+
+    if ytlive_programs_result.result_type == 'success':
+      if ytlive_programs_result.data_type == 'ytlive_programs':
+        return ytlive_programs_result.data
+      else:
+        raise GetLiveProgramError(ytlive_programs_result)
+    else:
+      raise GetLiveProgramError(ytlive_programs_result)
+
   else:
     raise GetLiveProgramError(f'Unknown service: {service}')
 
